attachmentIdsLoadingNoteModal property
Attachment IDs that are currently loading note content for the note modal.
Implementation
RxSet<String> attachmentIdsLoadingNoteModal = <String>{}.obs;
Attachment IDs that are currently loading note content for the note modal.
RxSet<String> attachmentIdsLoadingNoteModal = <String>{}.obs;