autoScrollEnabled property
Transient runtime state: whether auto-scroll is currently allowed. This is NOT a preference. It's suspended by any user manual scroll, and re-enabled automatically when the user returns to bottom AND the magnet preference is enabled.
Implementation
bool autoScrollEnabled = false;