expandedMessageGroupIds property
GroupIds (trimmed) whose message group is expanded in the messages list.
Implementation
final RxList<String> expandedMessageGroupIds = <String>[].obs;
GroupIds (trimmed) whose message group is expanded in the messages list.
final RxList<String> expandedMessageGroupIds = <String>[].obs;