DrawerConfig class

Configuration for the drawer.

Constructors

DrawerConfig({Widget? drawer, Widget? endDrawer, dynamic onDrawerChanged(bool isOpen)?, dynamic onEndDrawerChanged(bool isOpen)?, GlobalKey<ScaffoldState>? scaffoldKey})
const

Properties

drawer Widget?
The drawer to be displayed.
final
endDrawer Widget?
The end drawer to be displayed.
final
hashCode int
The hash code for this object.
no setterinherited
onDrawerChanged → dynamic Function(bool isOpen)?
Called when the drawer is opened or closed.
final
onEndDrawerChanged → dynamic Function(bool isOpen)?
Called when the end drawer is opened or closed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaffoldKey GlobalKey<ScaffoldState>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited