PupauLanguage enum

Supported languages for the plugin.

Inheritance
Available extensions

Values

en → const PupauLanguage

English (default)

de → const PupauLanguage

German

es → const PupauLanguage

Spanish

fr → const PupauLanguage

French

hi → const PupauLanguage

Hindi

it → const PupauLanguage

Italian

ko → const PupauLanguage

Korean

nl → const PupauLanguage

Dutch

pl → const PupauLanguage

Polish

pt → const PupauLanguage

Portuguese

sq → const PupauLanguage

Albanian

sv → const PupauLanguage

Swedish

tr → const PupauLanguage

Turkish

zh → const PupauLanguage

Chinese

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PupauLanguage>
A constant List of the values in this enum, in order of their declaration.