VoiceOption class

Constructors

VoiceOption({required String id, required String label, required String gender, required List<String> languages})
const
VoiceOption.fromJson(Map<String, dynamic> json)
factory

Properties

gender String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
label String
final
languages List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited