GroundingOrigin enum

Inheritance
Available extensions

Values

implicit → const GroundingOrigin
kbTool → const GroundingOrigin
webSearch → const GroundingOrigin
attachment → const GroundingOrigin
unknown → const GroundingOrigin

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsSnippetFetch bool

Available on GroundingOrigin, provided by the GroundingOriginParsing extension

KB snippet fetch (GET /grounding/chunks/:embeddingId) only ever makes sense for chunk-backed origins (2.2).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GroundingOrigin>
A constant List of the values in this enum, in order of their declaration.