GroundingVerification class

grounding.verification (3.2/3.3) — only meaningful when verificationStatus == DONE.

Constructors

GroundingVerification({required double score, required List<GroundingVerdict> verdicts, String? model, double? credit, int? timeMs})
GroundingVerification.fromMap(Map<String, dynamic> json)
factory

Properties

credit double?
final
hashCode int
The hash code for this object.
no setterinherited
model String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double
final
timeMs int?
final
verdicts List<GroundingVerdict>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verdictFor(int sourceId, int occurrence) GroundingVerdict?

Operators

operator ==(Object other) bool
The equality operator.
inherited