LoadingMessage class
Constructors
-
LoadingMessage({required String message, LoadingType? loadingType, ToolUseType? toolUseType, List<
ToolLoadingEntry> tools = const []})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- loadingType ↔ LoadingType?
-
getter/setter pair
- message ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tools
→ List<
ToolLoadingEntry> -
Optional list of active tool loadings (when loadingType == LoadingType.toolUse).
When empty, message / toolUseType represent a single tool loading.
final
- toolUseType ↔ ToolUseType?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited