MemoryAlways class

Constructors

MemoryAlways({required String memoryId, required String content, required String priority, String? category})
MemoryAlways.fromMap(Map<String, dynamic> json)
factory

Properties

category String?
final
content String
final
hashCode int
The hash code for this object.
no setterinherited
memoryId String
final
priority String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited