AttachmentTrimmingItem class

Attachment trimming item (per-file detail).

Constructors

AttachmentTrimmingItem({required String filename, required String action, required int estimatedTokensBefore, required int estimatedTokensAfter, required int estimatedTokensSaved, required String reason})

Properties

action String
final
estimatedTokensAfter int
final
estimatedTokensBefore int
final
estimatedTokensSaved int
final
filename String
final
hashCode int
The hash code for this object.
no setterinherited
reason String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic> json) AttachmentTrimmingItem