ToolUseSpreadsheetData class

Constructors

ToolUseSpreadsheetData({required String toolName, required Map<String, dynamic> toolArgs, required SpreadsheetToolResultType resultType, String? errorMessage, SpreadsheetSourceInfo? source, List<SpreadsheetColumnInfo> columns = const [], List<Map<String, dynamic>> rows = const [], int total = 0, int totalRows = 0, int offset = 0, int limit = 0, Map<String, dynamic>? row, String? message, List<SpreadsheetSummaryItem> summaryItems = const [], List<SpreadsheetDistinctItem> distinctItems = const [], dynamic raw})
ToolUseSpreadsheetData.fromToolUseMessage({required String toolName, required Map<String, dynamic> message, required Map<String, dynamic>? typeDetails})
factory

Properties

columns List<SpreadsheetColumnInfo>
final
distinctItems List<SpreadsheetDistinctItem>
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
limit int
final
message String?
final
offset int
final
raw → dynamic
final
resultType SpreadsheetToolResultType
final
row Map<String, dynamic>?
final
rows List<Map<String, dynamic>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source SpreadsheetSourceInfo?
final
summaryItems List<SpreadsheetSummaryItem>
final
toolArgs Map<String, dynamic>
final
toolName String
final
total int
final
totalRows int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited