SubagentSpawnInfo class

Constructors

SubagentSpawnInfo({required SubagentSpawnStatus status, required int runId, String? childConversationId, String? childConversationHashId, String? mode, String? note, SubagentOutcomeStatus? outcomeStatus, String? error})
SubagentSpawnInfo.fromJson(Map<String, dynamic> json)
factory

Properties

childConversationHashId String?
final
childConversationId String?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
mode String?
final
note String?
final
outcomeStatus SubagentOutcomeStatus?
final
runId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status SubagentSpawnStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited