ToolUseSubagentData class

Response payload for native tool subagent_spawn (actor SUBAGENT). See info[0].status: accepted (async), completed / error (sync).

Constructors

ToolUseSubagentData({required String message, required List<SubagentSpawnInfo> info, required List<String> errors})
ToolUseSubagentData.fromNativeMap(Map<String, dynamic> map)
factory

Properties

errors List<String>
final
firstInfo SubagentSpawnInfo?
First spawn info block, if any.
no setter
hashCode int
The hash code for this object.
no setterinherited
info List<SubagentSpawnInfo>
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited