TaskToolUiConfig class

UI configuration for the Task Tool (enabled + capabilities).

Constructors

TaskToolUiConfig({bool enabled = true, List<TaskToolCapability> capabilities = const [TaskToolCapability.read, TaskToolCapability.write]})
const

Properties

capabilities List<TaskToolCapability>
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toActorParameters() TaskToolActorParameters
Parameters saved in CREATE_TASK actor configuration (pattern like browser tool).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited