TaskUpdateArgs class

Constructors

TaskUpdateArgs({required String hashId, String? name, TaskStatus? status, TaskType? type, TaskTarget? target, int? targetId, String? cron, String? executionDate, String? timezone, String? endsAt, int? maxRetries, bool? silentTask, String? configurations})

Properties

configurations String?
final
cron String?
final
endsAt String?
final
executionDate String?
final
hashCode int
The hash code for this object.
no setterinherited
hashId String
final
maxRetries int?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
silentTask bool?
final
status TaskStatus?
final
target TaskTarget?
final
targetId int?
final
timezone String?
final
type TaskType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited