User class

Constructors

User({required String id, String? name, String? surname, String? nickname, DateTime? birthDate, required bool verified, required String username, required String language, required String image})
User.fromMap(Map<String, dynamic> json)
factory

Properties

birthDate DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
image String
getter/setter pair
language String
getter/setter pair
name String?
getter/setter pair
nickname String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surname String?
getter/setter pair
username String
getter/setter pair
verified bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited