VoiceSession class

Constructors

VoiceSession({required String voiceSessionId, required String voiceSessionToken, required VoiceAudioInputConfig inputConfig, required VoiceAudioOutputConfig outputConfig, required VoiceSessionLimits limits})
const
VoiceSession.fromMap(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
inputConfig VoiceAudioInputConfig
final
limits VoiceSessionLimits
final
outputConfig VoiceAudioOutputConfig
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
voiceSessionId String
final
voiceSessionToken String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited