AudioRecordingService class

Handles audio recording for voice messages. Uses record package (wav format).

Constructors

AudioRecordingService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentPath String?
getter/setter pair
isRecording Future<bool>
no setter
recorder → AudioRecorder
final

Static Methods

cancelRecording() Future<void>
Cancel recording without saving.
hasPermission() Future<bool>
Check if we have microphone permission.
requestPermission() Future<bool>
Request microphone permission. Returns true if granted. Shows settings dialog if permission is permanently denied.
startRecording() Future<String?>
Start recording. Returns the file path that will be used, or null if failed.
stopRecording() Future<File?>
Stop recording and return the audio file, or null if failed/not recording.