SSEService class

Constructors

SSEService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

buildAudioMultipartRequest({required String url, required File audioFile, required Map<String, String> headers, PupauLanguage? language}) Future<MultipartRequest?>
Builds multipart request matching API: sse, systemLang, customProperties, audio file (Content-Type: audio/mpeg).
createConversationSseGetStream(String assistantId, String conversationId, String conversationToken, {String? lastEventId, PupauChatController? chatController}) Future<Stream<SSEModel>?>
SSE (GET) for conversation history + catch-up.
createSSEStream(String assistantId, String conversationId, String conversationToken, String message, {bool isWebSearch = false, bool isExternalSearch = false, PupauChatController? chatController}) Future<Stream<SSEModel>?>
createSSEStreamAudio(String assistantId, String conversationId, String conversationToken, File audioFile, {bool isWebSearch = false, PupauChatController? chatController}) Future<Stream<SSEModel>?>
generateBody(String message) Map<String, dynamic>