ToolArgsDeltaService class

Constructors

ToolArgsDeltaService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearPreviewCache({required Map<String, String> toolIdByName, required Map<String, String> previewsById, required Map<String, String> titlesById, required Map<String, String> rawBuffersById}) → void
computePreview({required String previousBuffer, required String argsDelta}) ToolArgsDeltaComputation
extractDocumentPreview(String rawBuffer, Map<String, dynamic>? parsed) String?
extractDocumentTitle(Map<String, dynamic>? parsed) String?
extractFirstJsonStringValue(String rawBuffer) String?
Extracts the first JSON string value from a single-key object fragment, e.g. { "thought": "Hello -> returns Hello (best-effort, supports partial).
getPreviewContent({required String toolId, required Map<String, String> previewsById, required Map<String, String> rawBuffersById}) String
getPreviewTitle({required String toolId, required Map<String, String> titlesById}) String
hasPreview({required String toolId, required Map<String, String> previewsById, required Map<String, String> rawBuffersById}) bool
hasPreviewForToolName({required String toolName, required Map<String, String> toolIdByName, required Map<String, String> previewsById, required Map<String, String> rawBuffersById}) bool
resolveToolIdByName({required String toolName, required Map<String, String> toolIdByName}) String
tryParseToolArgs(String raw) Map<String, dynamic>?