ToolUseService class

Constructors

ToolUseService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getBrowserLoadingMessage(String name) ToolUseMessage
getToolDocumentActionDescription(ToolDocumentAction action) String
getToolDocumentActionEnum(String action) ToolDocumentAction
getToolUseDocumentsWithExportUrl(List<DocumentData> documents) List<DocumentData>
getToolUseIcon(ToolUseType? type) IconData?
getToolUseParameterTypeEnum(String type) ToolParameterType
getToolUseTypeEnum(String type, {String? nativeToolType}) ToolUseType
getToolUseTypeEnumFlat(String typeOrNativeToolType) ToolUseType
Like getToolUseTypeEnum, but treats native tool ids (e.g. "DOCUMENT") as first-class type values (no need for "NATIVE_TOOLS" wrapper).
isInitiallyExpandedTool(ToolUseType? type) bool
isModalToolUse(ToolUseType type) bool
isNativeTool(ToolUseType? type) bool
isSubagentTool(String? toolName) bool
SSE heartbeats and tool names use the subagent_ prefix (e.g. subagent_spawn).
resolveDashboardDocuments(List<PupauMessage> documentMessages) List<DocumentData>
setToolUseDocumentsRelatedAttachment(List<DocumentData> documents) List<DocumentData>