creditsEndedText constant

String const creditsEndedText

Implementation

static const String creditsEndedText =
    "If you want to buy more credits and continue the conversation or want to subscribe to a new subscription, click on the button below";