chat_page/components/message_elements/edit_message_dialog library
Functions
-
showEditMessageModal(
PupauMessage message) → void - Lets the user change their message text, then forks from the previous message and sends the new text (same idea as ChatGPT edit).