onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() {
super.onInit();
_chatController = Get.find<PupauChatController>();
_rebuild();
ever<List<PupauMessage>>(_chatController.messages, (_) => _rebuild());
if (Get.isRegistered<PupauAttachmentsController>()) {
_attachmentsListWorker = ever<List<Attachment>>(
Get.find<PupauAttachmentsController>().attachments,
(_) => _rebuild(),
);
}
}