config/pupau_config library
Classes
- AppBarConfig
- Configuration for the app bar.
- DrawerConfig
- Configuration for the drawer.
- FloatingConfig
- Configuration for floating widget mode. When the chat is shown as an overlay, it will use the specified width, height, and anchor position.
- PupauConfig
- Configuration class for Pupau Agent package
- SizedConfig
- Configuration for sized widget mode. When the chat is expanded, it will use the specified width and height.
Enums
- CloseButtonPosition
- CloseStyle
- FloatingAnchor
- Anchor position for floating overlay relative to the avatar widget.
- PupauLanguage
- Supported languages for the plugin.
- WidgetMode