VoiceOption class
Constructors
-
VoiceOption({required String id, required String label, required String gender, required List<
String> languages}) -
const
-
VoiceOption.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited