TaskDto class
Task DTO from task_list / task_get.
Constructors
- TaskDto({required int id, required String hashId, required String name, required int companyId, required String scope, required String origin, required int originId, required String target, required int targetId, required String status, required bool silentTask, String? cron, String? timezone, String? executionDate, String? endsAt, required String type, String? nextExecutionAt, String? lastExecutionAt, int? maxRetries, int? createdBy, int? updatedBy, String? createdAt, String? updatedAt})
-
TaskDto.fromJson(Map<
String, dynamic> json) -
factory
Properties
- companyId → int
-
final
- createdAt → String?
-
final
- createdBy → int?
-
final
- cron → String?
-
final
- endsAt → String?
-
final
- executionDate → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hashId → String
-
final
- id → int
-
final
- lastExecutionAt → String?
-
final
- maxRetries → int?
-
final
- name → String
-
final
- nextExecutionAt → String?
-
final
- origin → String
-
final
- originId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → String
-
final
- silentTask → bool
-
final
- status → String
-
final
- target → String
-
final
- targetId → int
-
final
- timezone → String?
-
final
- type → String
-
final
- updatedAt → String?
-
final
- updatedBy → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited