TaskExecutionDetailDto class
Task execution detail (task_execution_get).
- Inheritance
-
- Object
- TaskExecutionDto
- TaskExecutionDetailDto
Constructors
- TaskExecutionDetailDto({required int id, required String execHashId, required int taskId, required String hashId, required String origin, required String status, String? executionStart, String? executionEnd, required bool error, required int errorCount, required bool read, String? result, int? creditsCost, int? createdBy, int? updatedBy, String? createdAt, String? updatedAt, dynamic input, dynamic output, List? errorDetails})
-
TaskExecutionDetailDto.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createdAt → String?
-
finalinherited
- createdBy → int?
-
finalinherited
- creditsCost → int?
-
finalinherited
- error → bool
-
finalinherited
- errorCount → int
-
finalinherited
- errorDetails → List?
-
final
- execHashId → String
-
finalinherited
- executionEnd → String?
-
finalinherited
- executionStart → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hashId → String
-
finalinherited
- id → int
-
finalinherited
- input → dynamic
-
final
- origin → String
-
finalinherited
- output → dynamic
-
final
- read → bool
-
finalinherited
- result → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
finalinherited
- taskId → int
-
finalinherited
- updatedAt → String?
-
finalinherited
- updatedBy → int?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited