TaskExecutionDto class
Task execution DTO (list item).
- Implementers
Constructors
- TaskExecutionDto({required int id, required String execHashId, required int taskId, required String hashId, required String origin, required String status, String? executionStart, String? executionEnd, required bool error, required int errorCount, required bool read, String? result, int? creditsCost, int? createdBy, int? updatedBy, String? createdAt, String? updatedAt})
-
TaskExecutionDto.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createdAt → String?
-
final
- createdBy → int?
-
final
- creditsCost → int?
-
final
- error → bool
-
final
- errorCount → int
-
final
- execHashId → String
-
final
- executionEnd → String?
-
final
- executionStart → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hashId → String
-
final
- id → int
-
final
- origin → String
-
final
- read → bool
-
final
- result → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
- taskId → int
-
final
- updatedAt → String?
-
final
- updatedBy → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited