ToolRuntimeResponse<T> class
Constructors
-
ToolRuntimeResponse({required String actorId, required String message, List<
T> ? info, List<String> ? errors, ToolRuntimeCost? cost}) -
ToolRuntimeResponse.fromJson(Map<
String, dynamic> json, {T fromJsonT(Map<String, dynamic> )?}) -
factory
Properties
- actorId → String
-
final
- cost → ToolRuntimeCost?
-
final
- displayMessage → String
-
Primary display text: message + first error if present.
no setter
-
errors
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
info
→ List<
T> ? -
final
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited