ToolUseTaskData class
Parsed task tool message data for chat UI (info array + errors). For task_create, also stores task args from toolArgs for display.
Constructors
-
ToolUseTaskData({required String message, List<
String> ? errors, List<Map< ? info, String? subToolName, String? name, String? taskType, String? target, String? cron, String? timezone, bool read = false, bool write = false, bool execute = false})String, dynamic> > -
ToolUseTaskData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- cron → String?
-
Cron expression (e.g. "0 0 1 * *").
final
- displayMessage → String
-
no setter
-
errors
→ List<
String> ? -
final
- execute → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
info
→ List<
Map< ?String, dynamic> > -
final
- isCreateTask → bool
-
no setter
- message → String
-
final
- name → String?
-
Task name (create/update).
final
- read → bool
-
Capabilities from tool call (for create_task display).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subToolName → String?
-
Sub-tool name from SSE (e.g. task_create, task_list, task_update).
final
- target → String?
-
Target: AGENT | PIPELINE | MARKETPLACE.
final
- taskType → String?
-
Task type: RECURRING | ONE_TIME.
final
- timezone → String?
-
Timezone (e.g. "UTC").
final
- write → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited