LanguageService class

Service for language code conversions

Constructors

LanguageService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getCode(PupauLanguage language) String
Returns the 2-letter language code (e.g., 'en', 'de', 'es').
getCodeExtended(PupauLanguage language) String
Returns the extended locale code with country (e.g., 'en-US', 'it-IT', 'de-DE').