UserService class
Pupau user profile. syncUserProfileIfBearerChanged limits fetches to once per bearer token per app process unless the token changes.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getProfile(
) → Future< User?> -
Get Pupau user profile
Used for
USER_NAMEplaceholder tag replacement -
syncUserProfileIfBearerChanged(
String bearerToken) → Future< void> -
Fetches profile when
bearerTokenis non-empty and either this is the first time we see this token in the current app session or the token changed from the last successful sync. Skips duplicate calls for the same token until the next app restart (in-memory only).